@@ -8,6 +8,10 @@ class ApiSpaces(ApiBase):
     def space_by_name(self, space_name: str):
         return self.build_route("spaces/{space_name}".format(**locals()))
 
+    def get_images(self, space_name: str, cloud_account_name: str, region_id: str):
+        return self.build_route("spaces/{space_name}/cloud_accounts/{cloud_account_name}/regions/{region_id}/private_images"
+                                .format(**locals()))
+
     def space_users(self, space_name: str):
         """Astronauts"""
         return self.build_route("spaces/{space_name}/users".format(**locals()))
@@ -43,3 +47,8 @@ class ApiSpaces(ApiBase):
         return self.build_route(
             "spaces/{space_name}/users/{user_email}/space_role?value={space_role_name}".format(**locals())
         )
+
+    def space_cloud_account_regions(self, space_name: str, cloud_account_name: str):
+        return self.build_route(
+            "spaces/{space_name}/cloud_accounts/{cloud_account_name}/regions".format(**locals())
+        )
