@@ -14,7 +14,7 @@ from gateways.common.cs18_api_errors import UnauthorizedException, MaxRetriesExc
 from gateways.common.cs18_api_requests import (
     CreateInvitationsRequest,
     UpdateSpaceRequest,
-    ProductionEnvironment, DebuggingServiceValue, SpaceCloudAccountSettingsRequest)
+    ProductionEnvironment, DebuggingServiceValue, SpaceCloudAccountInfraSettingsRequest)
 from gateways.common.cs18_api_responses import (AccountStatusResponse, BlueprintFileResponse, BlueprintResponse,
                                                 CatalogForGetAllResponse, CatalogForGetResponse, CloudAccountResponse,
                                                 CreateProductionResponse, CreateSandboxResponse, GetSpaceResponse,
@@ -22,7 +22,8 @@ from gateways.common.cs18_api_responses import (AccountStatusResponse, Blueprint
                                                 ProductionResponseLean, RepositoryResponse, RoleListItemResponse,
                                                 SandboxResponse, SandboxResponseLean, TokenResponse,
                                                 UserInvitationResponse, UserPermittedToSpaceResponse,
-                                                UserForAllUsersResponse, CloudAccountInSpaceResponse)
+                                                UserForAllUsersResponse, CloudAccountInSpaceResponse, RegionResponse,
+                                                VerifyCloudProviderResponse)
 from gateways.n_session import NSession
 from gateways.the_gateway import TheGateway
 from gateways.utils import GatewayUtils, Utils
@@ -110,6 +111,12 @@ class Colony:
         json_response = json.loads(resp.text)
         return json_response
 
+    def remove_compute_service(self, cloud_account: str, compute_service: str):
+        method_url = self._api_root.settings.compute_services()
+        body = {"compute_service_name": f'{cloud_account}/{compute_service}'}
+        res = self.session.delete(url=method_url, json=body)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+
     def get_cloud_accounts_under_account(self) -> List[CloudAccountResponse]:
         method_url = self._api_root.settings.cloud_accounts()
         resp = self.session.get(url=method_url)
@@ -224,26 +231,12 @@ class Colony:
         template_json = json.loads(resp.text)
         return template_json
 
-    def unregister_aws_account(self, cloud_account_name: str):
-        method_url = self._api_root.settings.aws_cloud_account_by_name(
-            cloud_account_name
-        )
-        resp = self.session.delete(url=method_url)
-        GatewayUtils.handle_response(response=resp, return_codes=[200])
-
     def unregister_cloud_account(self, cloud_account_name: str):
         method_url = self._api_root.settings.cloud_accounts()
         body = {"cloud_account_name": cloud_account_name}
         resp = self.session.delete(url=method_url, json=body)
         GatewayUtils.handle_response(response=resp, return_codes=[200])
 
-    def unregister_azure_account(self, cloud_account_name: str):
-        method_url = self._api_root.settings.azure_cloud_account_by_name(
-            cloud_account_name
-        )
-        resp = self.session.delete(url=method_url)
-        GatewayUtils.handle_response(response=resp, return_codes=[200])
-
     def add_aws_s3_artifacts_repo(self, account_name: str, bucket_name: str):
         method_url = self._api_root.artifacts_repository.aws_s3_storage(
             space_name=self.space
@@ -514,7 +507,6 @@ class Colony:
                 time.sleep(30)  # need to make sure that the next call will not use the cached timedout error
                 self.end_sandbox(sandbox_id, False)
                 return
-            raise TimeoutError()
 
         GatewayUtils.handle_response(response=resp, return_codes=[202])
 
@@ -723,6 +715,12 @@ class Colony:
         GatewayUtils.handle_response(response=res, return_codes=[200])
         return GetSpaceResponse(json.loads(res.text))
 
+    def get_images(self, space_name: str, cloud_account_name: str, region_id: str):
+        url = self._api_root.spaces.get_images(space_name, cloud_account_name, region_id)
+        res = self.session.get(url)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+        return [Converters.get_image_response(x) for x in json.loads(res.text)]
+
     def update_space(self, space: str, update_space_request: UpdateSpaceRequest):
         url = self._api_root.spaces.space_by_name(space_name=space)
         response = self.session.put(url=url, json=update_space_request.__dict__)
@@ -749,29 +747,50 @@ class Colony:
         res = self.session.delete(url=method_url)
         GatewayUtils.handle_response(response=res, return_codes=[200])
 
-    def add_cloud_account_to_space(self, cloud_account: str, settings: SpaceCloudAccountSettingsRequest = None):
+    def add_cloud_account_to_space(self, cloud_account: str,
+                                   infra_settings: SpaceCloudAccountInfraSettingsRequest = None):
         method_url = self._api_root.spaces.space_cloud_accounts(self.space)
         data = {"name": cloud_account}
-        if settings:
-            data['internet_facing'] = settings.internet_facing
-            data['virtual_network'] = settings.virtual_network
-            if settings.subnets:
-                data['subnets'] = {'gateway_subnet': settings.subnets.gateway_subnet,
-                                   'management_subnet': settings.subnets.management_subnet,
-                                   'application_subnets': settings.subnets.application_subnets}
+        if infra_settings:
+            data['internet_facing'] = infra_settings.internet_facing
+            data['existing_infra'] = infra_settings.existing_infra
+            if infra_settings.existing_infra_sets:
+                existing_infra_sets = []
+                for infra_set in infra_settings.existing_infra_sets:
+                    existing_infra_sets.append(
+                        {
+                            'region': infra_set.region,
+                            'virtual_network': infra_set.virtual_network,
+                            'subnets': {'gateway_subnet': infra_set.subnets.gateway_subnet,
+                                        'management_subnet': infra_set.subnets.management_subnet,
+                                        'application_subnets': infra_set.subnets.application_subnets
+                                        } if infra_set.subnets else None
+                        }
+                    )
+                data['existing_infra_sets'] = existing_infra_sets
         res = self.session.post(url=method_url, json=data)
         GatewayUtils.handle_response(response=res, return_codes=[200])
 
-    def update_cloud_account_in_space(self, cloud_account: str, settings: SpaceCloudAccountSettingsRequest):
+    def update_cloud_account_in_space(self, cloud_account: str, infra_settings: SpaceCloudAccountInfraSettingsRequest):
         method_url = self._api_root.spaces.space_cloud_account(space_name=self.space, cloud_account=cloud_account)
         data = {
-            'internet_facing': settings.internet_facing,
-            'virtual_network': settings.virtual_network
+            'internet_facing': infra_settings.internet_facing,
+            'existing_infra': infra_settings.existing_infra
         }
-        if settings.subnets:
-            data['subnets'] = {'gateway_subnet': settings.subnets.gateway_subnet,
-                               'management_subnet': settings.subnets.management_subnet,
-                               'application_subnets': settings.subnets.application_subnets}
+        if infra_settings.existing_infra_sets:
+            existing_infra_sets = []
+            for infra_set in infra_settings.existing_infra_sets:
+                existing_infra_sets.append(
+                    {
+                        'region': infra_set.region,
+                        'virtual_network': infra_set.virtual_network,
+                        'subnets': {'gateway_subnet': infra_set.subnets.gateway_subnet,
+                                    'management_subnet': infra_set.subnets.management_subnet,
+                                    'application_subnets': infra_set.subnets.application_subnets
+                                    } if infra_set.subnets else None
+                    }
+                )
+            data['existing_infra_sets'] = existing_infra_sets
         res = self.session.put(url=method_url, json=data)
         GatewayUtils.handle_response(response=res, return_codes=[200])
 
@@ -894,6 +913,22 @@ class Colony:
         sso_enabled_url = self._api_root.account.set_sso_enabled(account_name)
         self.post_request(sso_enabled_url, {"enabled": enabled}, return_codes=[200])
 
+    def get_space_cloud_account_regions(self, space_name: str, cloud_account_name: str) -> List[RegionResponse]:
+        method_url = self._api_root.spaces.space_cloud_account_regions(space_name=space_name,
+                                                                       cloud_account_name=cloud_account_name)
+        resp = self.session.get(url=method_url)
+        GatewayUtils.handle_response(response=resp, return_codes=[200])
+        regions_json = json.loads(resp.text)
+        return [Converters.create_space_cloud_account_regions_response(region) for region in regions_json]
+
+    def verify_cloud_account(self, cloud_account_name: str) -> VerifyCloudProviderResponse:
+        method_url = self._api_root.settings.verify_cloud_account()
+        data = {"cloud_account_name": cloud_account_name}
+        res = self.session.put(url=method_url, json=data)
+        GatewayUtils.handle_response(response=res, return_codes=[200])
+        verify_json = json.loads(res.text)
+        return Converters.create_verify_response(verify_json)
+
 
 class SandboxesHandler:
     def __init__(self):
