@@ -798,7 +798,8 @@ class Converters:
                         resource_type=resource["resource_type"],
                         resource_name=resource["resource_name"],
                         resource_id=resource["resource_id"],
-                        resource_status=resource["resource_status"]
+                        resource_status=resource["resource_status"],
+                        resource_valid=resource["resource_valid"]
                     )
                 )
         return resources
