@@ -847,11 +847,13 @@ class VerifyCloudProviderResourceResponse:
                  resource_type: str,
                  resource_name: str,
                  resource_id: str = None,
-                 resource_status: str = None):
+                 resource_status: str = None,
+                 resource_valid: bool = False):
         self.resource_type = resource_type
         self.resource_name = resource_name
         self.resource_id = resource_id
         self.resource_status = resource_status
+        self.resource_valid = resource_valid
 
 
 class VerifyCloudProviderResponse:
